package fr.faraphel.consumer

import fr.faraphel.consumer.kafka.Consumer
import fr.faraphel.consumer.rest.TemperatureEndpoint
import fr.faraphel.common.error.MissingEnvironmentException
import io.quarkus.runtime.QuarkusApplication
import io.quarkus.runtime.annotations.QuarkusMain
import java.time.Instant


@QuarkusMain
class Main : QuarkusApplication {
    override fun run(vararg args: String?): Int {
        // get the kafka server address
        val kafkaServer = System.getenv("KAFKA_BOOTSTRAP_SERVERS")
            ?: throw MissingEnvironmentException("KAFKA_BOOTSTRAP_SERVERS")

        // get the topic name
        val topicTemperature: String = System.getenv("TEMPERATURE_TOPIC")
            ?: throw MissingEnvironmentException("TEMPERATURE_TOPIC")

        // create a consumer that will print the received values in the input topic
        val consumer = Consumer(
            server=kafkaServer,
            topic=topicTemperature
        ) { message ->
            // clean the values in the record
            val messageInstant = Instant.ofEpochMilli(message.timestamp())
            val messageContent = message.value()
            // print the value
            println("[${timeFormatter.format(messageInstant)}] ${messageContent}°F")
            // update the value for the API
            TemperatureEndpoint.updateData(messageContent, messageInstant)
        }

        // indefinitely consume new values
        consumer.consumeForever()

        return 0
    }
}
