package fr.faraphel.consumer.rest

import com.google.gson.Gson
import jakarta.ws.rs.GET
import jakarta.ws.rs.Path
import jakarta.ws.rs.Produces
import jakarta.ws.rs.core.MediaType
import java.time.Instant


/**
 * This API endpoint return the latest temperature measured (in Fahrenheit)
 */
@Path("/v1/temperature")
class TemperatureEndpoint {
    companion object {
        val jsonParser = Gson()  ///< the json parser

        private var temperature: Double? = null  ///< the latest temperature value
        private var time: Instant? = null  /// < the time of the latest value

        /**
         * Setter to update the latest temperature value
         * @param temperature the new temperature value
         */
        fun updateData(temperature: Double, time: Instant) {
            this.temperature = temperature
            this.time = time
        }
    }

    /**
     * Handler for a GET request on this endpoint
     * @return the latest temperature measured
     */
    @GET
    @Produces(MediaType.APPLICATION_JSON)
    fun get(): String = jsonParser.toJson(mapOf(
        "value" to temperature,
        "time" to time?.toEpochMilli(),
        "unit" to "Fahrenheit"
    ))
}
