package fr.faraphel.converter

import fr.faraphel.common.error.MissingEnvironmentException
import fr.faraphel.common.temperature.celsius
import fr.faraphel.converter.kafka.Converter
import io.quarkus.runtime.QuarkusApplication
import io.quarkus.runtime.annotations.QuarkusMain
import kotlin.time.Duration.Companion.seconds
import kotlin.time.toJavaDuration


@QuarkusMain
class Main : QuarkusApplication {
    override fun run(vararg args: String?): Int {
        // get the kafka server address
        val kafkaServer = System.getenv("KAFKA_BOOTSTRAP_SERVERS")
            ?: throw MissingEnvironmentException("KAFKA_BOOTSTRAP_SERVERS")

        // get the topics names
        val topicTemperatureCelsius: String = System.getenv("TEMPERATURE_CELSIUS_TOPIC")
            ?: throw MissingEnvironmentException("TEMPERATURE_CELSIUS_TOPIC")
        val topicTemperatureFahrenheit: String = System.getenv("TEMPERATURE_FAHRENHEIT_TOPIC")
            ?: throw MissingEnvironmentException("TEMPERATURE_FAHRENHEIT_TOPIC")

        // create a converter that will convert values coming from the Celsius topic to the Fahrenheit topic
        val converter = Converter(
            server=kafkaServer,
            inputTopic=topicTemperatureCelsius,
            outputTopic=topicTemperatureFahrenheit,
        ) { temperature -> temperature.celsius.asFahrenheit }

        // start converting values
        converter.start()

        // indefinitely wait for the converter to be paused
        while (!converter.isPaused)
            Thread.sleep(1.seconds.toJavaDuration())

        return 0
    }
}
