package fr.faraphel.producer

import fr.faraphel.common.error.MissingEnvironmentException
import fr.faraphel.producer.kafka.TemperatureProducer
import io.quarkus.runtime.QuarkusApplication
import io.quarkus.runtime.annotations.QuarkusMain


@QuarkusMain
class Main : QuarkusApplication {
    override fun run(vararg args: String?): Int {
        // get the kafka server address
        val kafkaServer = System.getenv("KAFKA_BOOTSTRAP_SERVERS")
            ?: throw MissingEnvironmentException("KAFKA_BOOTSTRAP_SERVERS")

        // get the topic name
        val topicTemperature: String = System.getenv("TEMPERATURE_TOPIC")
            ?: throw MissingEnvironmentException("TEMPERATURE_TOPIC")

        // get the location of the temperature to get
        val location = System.getenv("TEMPERATURE_LOCATION")
            ?: throw MissingEnvironmentException("TEMPERATURE_LOCATION")

        // parse the location to get the latitude and longitude
        val (latitude, longitude) = location.split(",").map { coordinate -> coordinate.trim().toDouble() }

        // create a producer that will generate temperature values based on the current temperature.
        val producer = TemperatureProducer(
            server=kafkaServer,
            latitude=latitude,
            longitude=longitude,
            topic=topicTemperature
        )

        // indefinitely produce new temperatures values
        producer.produceForever()

        return 0
    }
}
